@@ -806,8 +806,6 @@ class CameraDevice(Protocol):
     async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
     async def get_frames(self, prebuffer_duration: int = 0) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_motion_frames(self) -> AsyncGenerator[MotionFrame, None]: ...
-    async def get_ffmpeg_path(self) -> str: ...
-    async def get_ice_servers(self) -> list[IceServer]: ...
 
     async def get_value(
         self, state_name: str
@@ -953,6 +951,14 @@ CameraDeselectedCallback = Union[
 ]
 
 
+# CoreManager
+@runtime_checkable
+class CoreManager(Protocol):
+    async def get_ffmpeg_path(self) -> str: ...
+    async def get_ice_servers(self) -> list[IceServer]: ...
+    async def get_server_addresses(self) -> list[str]: ...
+
+
 # DeviceManager
 DeviceManagerEventType = Literal[
     "cameraSelected",
@@ -1096,6 +1102,7 @@ class PluginAPI(Protocol[PA]):
     config_file: str
     config_service: PluginConfigService
     storage_controller: StorageController[PA]
+    core_manager: CoreManager
     device_manager: DeviceManager
 
     def on(self, event: APIEventType, listener: Callback) -> "PluginAPI": ...
